@@ -64,17 +64,22 @@ if nm['127.0.0.1'].has_tcp(22):     # is there any information for port 22/tcp o
 # a more usefull example :
 for host in nm.all_hosts():
     print('----------------------------------------------------')
-    print('Host : %s (%s)' % (host, nm[host].hostname()))
-    print('State : %s' % nm[host].state())
+    print('Host : {0} ({1})'.format(host, nm[host].hostname()))
+    print('State : {0}'.format(nm[host].state()))
 
     for proto in nm[host].all_protocols():
         print('----------')
-        print('Protocol : %s' % proto)
+        print('Protocol : {0}'.format(proto))
 
         lport = list(nm[host][proto].keys())
         lport.sort()
         for port in lport:
-            print('port : %s\tstate : %s' % (port, nm[host][proto][port]['state']))
+            print('port : {0}\tstate : {1}'.format(port, nm[host][proto][port]))
+
+
+print('----------------------------------------------------')
+# print result as CSV
+print(nm.csv())
 
 
 
@@ -89,8 +94,6 @@ for host, status in hosts_list:
 
 
 
-
-
 print('----------------------------------------------------')
 # Asynchronous usage of PortScannerAsync
 
